@@ -1,6 +1,5 @@
 <?php
 
-require_once 'PHPUnit/Framework.php';
  
 class databaseGitTest extends PHPUnit_Framework_TestCase
 {
@@ -14,7 +13,6 @@ class databaseGitTest extends PHPUnit_Framework_TestCase
   public function testGit()
   {
     $database_git = Database_Git::getInstance();
-    $database_git->verify ();
     $database_git->optimize ();
     $directory = "/var/www/bibledit";
     $output = "x/y/z";
@@ -40,4 +38,3 @@ class databaseGitTest extends PHPUnit_Framework_TestCase
 
 ?>
 
-
