@@ -1,9 +1,6 @@
 <?php
 
 
-require_once 'PHPUnit/Framework.php';
-
- 
 class odfdomTextTest extends PHPUnit_Framework_TestCase
 {
 
@@ -41,7 +38,7 @@ private $temporary_folder;
     $odf_text->addText ("Paragraph Three");
     @unlink ("/tmp/OdfTextTest1.odt");
     $odf_text->save ("/tmp/OdfTextTest1.odt");
-    exec ("odt2txt /tmp/OdfTextTest1.odt", $output, &$return_var);
+    exec ("odt2txt /tmp/OdfTextTest1.odt", $output, $return_var);
     $this->assertEquals (array ("", "Paragraph One", "", "Paragraph Two", "", "Heading One", "===========", "", "Paragraph Three", ""), $output);
     @unlink ("/tmp/OdfTextTest1.odt");
   }
@@ -53,7 +50,7 @@ private $temporary_folder;
     $odf_text->addText ("Should create new paragraph automatically");
     @unlink ("/tmp/OdfTextTest2.odt");
     $odf_text->save ("/tmp/OdfTextTest2.odt");
-    exec ("odt2txt /tmp/OdfTextTest2.odt", $output, &$return_var);
+    exec ("odt2txt /tmp/OdfTextTest2.odt", $output, $return_var);
     $this->assertEquals (array ("", "Should create new paragraph automatically", ""), $output);
     @unlink ("/tmp/OdfTextTest2.odt");
   }
@@ -69,7 +66,7 @@ private $temporary_folder;
     $odf_text->addText (".");
     @unlink ("/tmp/OdfTextTest3.odt");
     $odf_text->save ("/tmp/OdfTextTest3.odt");
-    exec ("odt2txt /tmp/OdfTextTest3.odt", $output, &$return_var);
+    exec ("odt2txt /tmp/OdfTextTest3.odt", $output, $return_var);
     $this->assertEquals (array ("", "Text1†", "", "Note1.", "", ".", ""), $output);
     @unlink ("/tmp/OdfTextTest3.odt");
   }
@@ -78,4 +75,3 @@ private $temporary_folder;
 }
 ?>
 
-
