@@ -71,14 +71,17 @@ class Bootstrap
     // Thus the name of the class determines which file gets required.
     // The above implies that all classes translate to files and folders in lower case.
     // An exception is made for the Zend_* classes.
-    function __autoload($class_name)
+    function __autoload ($class_name)
     {
       if (substr ($class_name, 0, 4) != "Zend") {
         $class_name = strtolower ($class_name);
       }
-      $path = str_replace("_", "/", $class_name);
+      $path = str_replace ("_", "/", $class_name);
       require_once $path.".php";
     }
+    // Register the function.
+    spl_autoload_register ('__autoload');
+    
     
     // Disable magic quotes.
     if ( (function_exists("get_magic_quotes_gpc")) && get_magic_quotes_gpc() ) {
@@ -86,9 +89,15 @@ class Bootstrap
       foreach($_POST   as $k => $v) $_POST  [$k] = stripslashes($v);
       foreach($_COOKIE as $k => $v) $_COOKIE[$k] = stripslashes($v);
     }
+
+    // General configuration database.    
+    $database_config_general = Database_Config_General::getInstance();
+
+    // The site's timezone.
+    $timezone = $database_config_general->getTimezone ();
+    date_default_timezone_set ($timezone);
     
     // The localization.
-    $database_config_general = Database_Config_General::getInstance();
     $language = $database_config_general->getSiteLanguage ();
     if ($language != "") {
       putenv("LANGUAGE=$language");
@@ -111,4 +120,4 @@ class Bootstrap
 }
 
 
-?>
+?>
\ No newline at end of file
