@@ -10,12 +10,12 @@ class Filter_Archive
   * Returns the path to the compressed archive it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function zipFile ($filename, $show_errors)
+  public static function zipFile ($filename, $show_errors)
   {
     $zippedfile = uniqid (sys_get_temp_dir() . "/") . ".zip";
     $dirname = escapeshellarg (dirname ($filename));
     $basename = escapeshellarg (basename ($filename));
-    exec ("cd $dirname && zip $zippedfile $basename 2>&1", $output, &$return_var);
+    exec ("cd $dirname && zip $zippedfile $basename 2>&1", $output, $return_var);
     if ($return_var != 0) {
       @unlink ($zippedfile);
       $zippedfile = NULL;
@@ -36,11 +36,11 @@ class Filter_Archive
   * Returns the path to the compressed archive it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function zipFolder ($folder, $show_errors)
+  public static function zipFolder ($folder, $show_errors)
   {
     $zippedfile = uniqid (sys_get_temp_dir() . "/") . ".zip";
     $folder = escapeshellarg ($folder);
-    exec ("cd $folder && zip -r $zippedfile * 2>&1", $output, &$return_var);
+    exec ("cd $folder && zip -r $zippedfile * 2>&1", $output, $return_var);
     if ($return_var != 0) {
       @unlink ($zippedfile);
       unset ($zippedfile);
@@ -61,12 +61,12 @@ class Filter_Archive
   * Returns the path to the folder it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function unzip ($file, $show_errors) 
+  public static function unzip ($file, $show_errors) 
   {
     $file = escapeshellarg ($file);
     $folder = uniqid (sys_get_temp_dir() . "/");
     mkdir ($folder);
-    exec ("unzip -o -d $folder $file 2>&1", $output, &$return_var);
+    exec ("unzip -o -d $folder $file 2>&1", $output, $return_var);
     if ($return_var != 0) {
       Filter_Rmdir::rmdir ($folder);
       $folder = NULL;
@@ -85,12 +85,12 @@ class Filter_Archive
   * Returns the path to the compressed archive it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function tarGzipFile ($filename, $show_errors)
+  public static function tarGzipFile ($filename, $show_errors)
   {
     $tarball = uniqid (sys_get_temp_dir() . "/") . ".tar.gz";
     $dirname = escapeshellarg (dirname ($filename));
     $basename = escapeshellarg (basename ($filename));
-    exec ("cd $dirname && tar -czf $tarball $basename 2>&1", $output, &$return_var);
+    exec ("cd $dirname && tar -czf $tarball $basename 2>&1", $output, $return_var);
     if ($return_var != 0) {
       @unlink ($tarball);
       unset ($tarball);
@@ -111,11 +111,11 @@ class Filter_Archive
   * Returns the path to the compressed archive it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function tarGzipFolder ($folder, $show_errors)
+  public static function tarGzipFolder ($folder, $show_errors)
   {
     $tarball = uniqid (sys_get_temp_dir() . "/") . ".tar.gz";
     $folder = escapeshellarg ($folder);
-    exec ("cd $folder && tar -czf $tarball . 2>&1", $output, &$return_var);
+    exec ("cd $folder && tar -czf $tarball . 2>&1", $output, $return_var);
     if ($return_var != 0) {
       @unlink ($tarball);
       unset ($tarball);
@@ -136,12 +136,12 @@ class Filter_Archive
   * Returns the path to the folder it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function untargz ($file, $show_errors)
+  public static function untargz ($file, $show_errors)
   {
     $file = escapeshellarg ($file);
     $folder = uniqid (sys_get_temp_dir() . "/");
     mkdir ($folder);
-    exec ("cd $folder && tar zxf $file 2>&1", $output, &$return_var);
+    exec ("cd $folder && tar zxf $file 2>&1", $output, $return_var);
     if ($return_var != 0) {
       Filter_Rmdir::rmdir ($folder);
       $folder = NULL;
@@ -161,7 +161,7 @@ class Filter_Archive
   * Returns the path to the folder it created.
   * If $show_errors is true, it outputs errors in html.
   */
-  public function uncompress ($file, $show_errors)
+  public static function uncompress ($file, $show_errors)
   {
     // Tar (.tar) archives, including those compressed with gzip (.tar.gz, .tgz), bzip (.tar.bz, .tbz), bzip2 (.tar.bz2, .tbz2), compress (.tar.Z, .taz), lzop (.tar.lzo, .tzo) and lzma (.tar.lzma)
     // Zip archives (.zip)
@@ -189,4 +189,4 @@ class Filter_Archive
 
 }
 
-?>
+?>
\ No newline at end of file
