@@ -75,10 +75,12 @@ class Filter_Text
   
   public $onlinebible_text; // Object for creating the input file for the Online Bible compiler.
   
+  public $esword_text; // Object for creating the Bible module for eSword.
+  
   /**
   * Class constructor.
   */
-  public function __construct ()
+  public function __construct ($bible)
   {
     $this->createdOdfStyles = array ();
     $this->numberOfChaptersPerBook = array ();
@@ -104,6 +106,7 @@ class Filter_Text
     $this->html_text_standard = new Html_Text (gettext ("Bible"));
     $this->html_text_linked = new Html_Text (gettext ("Bible"));
     $this->onlinebible_text = new Onlinebible_Text ();
+    $this->esword_text = new Esword_Text ($bible);
   }
   
 
@@ -248,6 +251,8 @@ class Filter_Text
                       $s = str_replace (Filter_Character::softHyphen (), "", $s); // Remove possible soft hyphen.
                       $database_books = Database_Books::getInstance ();
                       $this->currentBookIdentifier = $database_books->getIdFromUsfm ($s);
+                      // Output to some export formats.
+                      $this->esword_text->newBook ($this->currentBookIdentifier);
                       // Reset chapter and verse numbers.
                       $this->currentChapterNumber = 0;
                       $this->numberOfChaptersPerBook[$this->currentBookIdentifier] = 0;
@@ -361,10 +366,6 @@ class Filter_Text
   */
   private function processUsfm ()
   {
-    // The linked web file starts with a link back to the index.
-    $this->html_text_linked->newParagraph ();
-    $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement,  "index.html", "", gettext ("Index"), "", gettext ("Index"));
-
     // Go through the USFM code.
     $processedBooksCount = 0;
     $this->usfmMarkersAndTextPointer = 0;
@@ -420,13 +421,6 @@ class Filter_Text
                     $this->resetNoteCitations ('book');
                     // Online Bible.
                     $this->onlinebible_text->storeData ();
-                    // Linked web: Links to all the chapters, and back to the start.
-                    $this->html_text_linked->newParagraph ();
-                    $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "", "start", "", "", "");
-                    $this->html_text_linked->addText (gettext ("Chapter") . " |");
-                    for ($i = 1; $i <= $this->numberOfChaptersPerBook[$this->currentBookIdentifier]; $i++) {
-                      $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "#chapter$i", "", "Chapter $i", "", " $i |");
-                    }
                     // Done.
                     break;
                   }
@@ -556,7 +550,7 @@ class Filter_Text
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
                 $this->html_text_linked->closeTextStyle ();
-                
+
                 $this->onlinebible_text->storeData ();
 
                 // Get the chapter number.
@@ -590,11 +584,6 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->newHeading1 ($runningHeader, true);
                 $this->odf_text_notes->newHeading1 ($runningHeader, false);
                 
-                // In the linked web version, each chapter number gets linked to, and links to, the start of the book.
-                $this->html_text_linked->newParagraph ();
-                $hrefId = "chapter" . $this->currentChapterNumber;
-                $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "#start", $hrefId, gettext ("Go to start"), "", gettext ("Go to start"));
-
                 // This is the phase of outputting the chapter number in the text body. 
                 // The chapter number is only output when there is more than one chapter in a book.
                 if ($this->numberOfChaptersPerBook[$this->currentBookIdentifier] > 1) {
@@ -637,7 +626,10 @@ class Filter_Text
                     $this->html_text_linked->addText ($number);
                   }
                 }
-
+                
+                // Output chapter number for other formats.
+                $this->esword_text->newChapter ($this->currentChapterNumber);
+                
                 // Open a paragraph for the notes. It takes the style of the footnote content marker, usually 'ft'. 
                 // This is done specifically for the version that has the notes only.
                 $this->ensureNoteParagraphStyle ($this->standardContentMarkerFootEndNote, $this->styles[$this->standardContentMarkerFootEndNote]);
@@ -756,8 +748,9 @@ class Filter_Text
                 }
                 // Unset the chapter variable, whether it was used or not. This makes it ready for subsequent use. 
                 unset ($this->outputChapterTextAtFirstVerse);
-                // Online Bible.
+                // Other export formats.
                 $this->onlinebible_text->newVerse ($this->currentBookIdentifier, $this->currentChapterNumber, $this->currentVerseNumber);
+                $this->esword_text->newVerse ($this->currentVerseNumber);
                 // Done.
                 break;
               }
@@ -916,6 +909,7 @@ class Filter_Text
           $this->html_text_standard->addText ($currentItem);
           $this->html_text_linked->addText ($currentItem);
           $this->onlinebible_text->addText ($currentItem);
+          $this->esword_text->addText ($currentItem);
         }
       }
     }
@@ -1532,4 +1526,3 @@ class Filter_Text
 }
 
 ?>
-
